lemonldap-ng (0.9.4.1-3) lemonldap-ng-portal/lib/Lemonldap/NG/Portal.pm

Summary

 lemonldap-ng-portal/lib/Lemonldap/NG/Portal.pm |   18 ++++++++++--------
 1 file changed, 10 insertions(+), 8 deletions(-)

    
download this patch

Patch contents

--- lemonldap-ng-0.9.4.1.orig/lemonldap-ng-portal/lib/Lemonldap/NG/Portal.pm
+++ lemonldap-ng-0.9.4.1/lemonldap-ng-portal/lib/Lemonldap/NG/Portal.pm
@@ -15,6 +15,8 @@
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 Lemonldap::NG::Portal - The authentication portal part of Lemonldap::NG Web-SSO
@@ -50,7 +52,7 @@
   }
   else {
       # Write here the html form used to authenticate with CGI methods.
       # $portal->error returns the error message if authentification failed
       # You can force the language in error like this :
       #   print $portal->error('fr')
       # Warning: by defaut, input names are "user" and "password"
@@ -112,7 +114,7 @@
 
 =head3 B<Authentication>
 
-If a user isn't authenticated and attemps to connect to an area protected by a
+If a user isn't authenticated and attempts to connect to an area protected by a
 Lemonldap::NG compatible handler, he is redirected to a portal. The portal
 authenticates user with a ldap bind by default, but you can also use another
 authentication sheme like using x509 user certificates (see
@@ -143,7 +145,7 @@
 documentation),
 
 =item * create Perl expression to define user groups (using ldap attributes):
-optionnal, this mechanism is available with Lemonldap::NG::*::SharedConf
+optional, this mechanism is available with Lemonldap::NG::*::SharedConf
 modules,
 
 =item * create an array foreach virtual host associating URI regular
@@ -201,7 +203,7 @@
 
 =back
 
-It is also recommanded to use the C<groups> mechanism to avoid having to
+It is also recommended to use the C<groups> mechanism to avoid having to
 evaluate a long expression at each HTTP request:
 
   locationRules => {
@@ -223,7 +225,7 @@
 
 =back
 
-It is also recommanded to use Perl expressions to avoid requiering the LDAP
+It is also recommended to use Perl expressions to avoid requiering the LDAP
 server more than 2 times per authentication.
 
 =head3 B<Accounting>
@@ -251,7 +253,7 @@
 
 =over
 
-=item * B<keys> are the names of the choosen headers
+=item * B<keys> are the names of the chosen headers
 
 =item * B<values> are perl expressions where you can use user datas stored in
 the global store by calling them C<$E<lt>varnameE<gt>>.
@@ -372,7 +374,7 @@
 
 =over
 
-=item * ldap : authentification is done by LDAP bind
+=item * ldap : authentication is done by LDAP bind
 
 =item * SSL : the portal reads SSL variables issued from Apache SSL
 authentication. See L<Lemonldap::NG::Portal::AuthSSL> for more.
@@ -404,7 +406,7 @@
 L<Lemonldap::NG::Common::Conf> for more
 
 =item * caPath, caFile : if you use ldap+tls you can overwrite cafile or capath
-options with those parameters. This is usefull if you use a shared
+options with those parameters. This is useful if you use a shared
 configuration.
 
 =item * ldapPpolicyControl : set it to 1 if you want to use LDAP Password
@@ -50,7 +52,7 @@
   else {
       # Write here the html form used to authenticate with CGI methods.
-      # $portal->error returns the error message if authentification failed
+      # $portal->error returns the error message if authentication failed
       # You can force the language in error like this :
       #   print $portal->error('fr')